@@ -13,8 +13,8 @@ my $rtc = MIDI::RtController->new( input => $in, output => $out );
 $rtc->add_filter(
     'echo',
     all => sub {
-        my ($dt, $event) = @_;
-        print "dt: $dt, ev: ", join( ', ', @$event ), "\n"
+        my ( $port, $dt, $event ) = @_;
+        print "port: $port, dt: $dt, ev: ", join( ', ', @$event ), "\n"
             unless $event->[0] eq 'clock';
         return 0;
     }
